==> kyua-0.11.tar.gz: kyua-0.11/utils/format/containers.hpp <==
// Copyright 2014 Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// * Redistributions of source code must retain the above copyright
//   notice, this list of conditions and the following disclaimer.
// * Redistributions in binary form must reproduce the above copyright
//   notice, this list of conditions and the following disclaimer in the
//   documentation and/or other materials provided with the distribution.
// * Neither the name of Google Inc. nor the names of its contributors
//   may be used to endorse or promote products derived from this software
//   without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

/// \file utils/format/containers.hpp
/// Overloads to support formatting various base container types.

#if !defined(UTILS_FORMAT_CONTAINERS_HPP)
#define UTILS_FORMAT_CONTAINERS_HPP

#include <map>
#include <ostream>
#include <set>
#include <vector>

#include "utils/shared_ptr.hpp"

// This is ugly but necessary for C++ name resolution.  Unsure if we'd do it
// differently...
namespace std {


template< typename K, typename V >
std::ostream& operator<<(std::ostream&, const std::map< K, V >&);

template< typename T >
std::ostream& operator<<(std::ostream&, const std::shared_ptr< T >&);

template< typename T >
std::ostream& operator<<(std::ostream&, const std::set< T >&);

template< typename T >
std::ostream& operator<<(std::ostream&, const std::vector< T >&);


}  // namespace std

#endif  // !defined(UTILS_FORMAT_CONTAINERS_HPP)

==> kyua_0.13.orig.tar.gz: kyua-0.13/utils/format/containers.hpp <==
// Copyright 2014 The Kyua Authors.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// * Redistributions of source code must retain the above copyright
//   notice, this list of conditions and the following disclaimer.
// * Redistributions in binary form must reproduce the above copyright
//   notice, this list of conditions and the following disclaimer in the
//   documentation and/or other materials provided with the distribution.
// * Neither the name of Google Inc. nor the names of its contributors
//   may be used to endorse or promote products derived from this software
//   without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

/// \file utils/format/containers.hpp
/// Overloads to support formatting various base container types.

#if !defined(UTILS_FORMAT_CONTAINERS_HPP)
#define UTILS_FORMAT_CONTAINERS_HPP

#include <map>
#include <ostream>
#include <set>
#include <utility>
#include <vector>

#include "utils/shared_ptr.hpp"

// This is ugly but necessary for C++ name resolution.  Unsure if we'd do it
// differently...
namespace std {


template< typename K, typename V >
std::ostream& operator<<(std::ostream&, const std::map< K, V >&);

template< typename T1, typename T2 >
std::ostream& operator<<(std::ostream&, const std::pair< T1, T2 >&);

template< typename T >
std::ostream& operator<<(std::ostream&, const std::shared_ptr< T >);

template< typename T >
std::ostream& operator<<(std::ostream&, const std::set< T >&);

template< typename T >
std::ostream& operator<<(std::ostream&, const std::vector< T >&);


}  // namespace std

#endif  // !defined(UTILS_FORMAT_CONTAINERS_HPP)
